"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const qs = require("qs");
class DrupalJsonApiParams {
    constructor() {
        this.filter = {};
        this.group = {};
        this.sort = [];
        this.include = [];
        this.page = undefined;
        this.fields = {};
    }
    addFields(type, fields) {
        this.fields[type] = fields.join(',');
        return this;
    }
    addSort(path, direction) {
        let prefix = '';
        if (direction !== undefined && direction === 'DESC') {
            prefix = '-';
        }
        this.sort = this.sort.concat(prefix + path);
        return this;
    }
    addPageLimit(limit) {
        this.page = { limit };
        return this;
    }
    addInclude(fields) {
        this.include = this.include.concat(fields);
        return this;
    }
    addGroup(name, conjunction = 'OR', memberOf) {
        this.group[name] = Object.assign({ conjunction }, (memberOf !== undefined && { memberOf }));
        return this;
    }
    addFilter(path, value, operator = '=', group) {
        if (operator === '=' && group === undefined && this.filter[path] === undefined) {
            this.filter[path] = value;
            return this;
        }
        const name = this.getIndexId(this.filter, path);
        this.filter[name] = {
            condition: Object.assign(Object.assign({ path,
                value }, (operator !== '=' && { operator })), (group !== undefined && { group })),
        };
        return this;
    }
    getIndexId(obj, proposedKey) {
        let key;
        if (obj[proposedKey] === undefined) {
            key = proposedKey;
        }
        else {
            key = Object.keys(obj).length.toString();
        }
        return key;
    }
    getQueryString() {
        const data = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, (this.filter !== {} && { filter: this.filter })), (this.group !== {} && { group: this.group })), (!!this.include.length && { include: this.include.join(',') })), (this.page !== undefined && { page: this.page })), (!!this.sort.length && { sort: this.sort.join(',') })), (this.fields !== {} && { fields: this.fields }));
        return qs.stringify(data);
    }
}
exports.DrupalJsonApiParams = DrupalJsonApiParams;
